==> hqsoft_core-0.0.40.tar.gz: lib/core_base/utility/util.dart <==
import 'dart:async';
import 'dart:io';

import 'package:connectivity/connectivity.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_datetime_picker/flutter_datetime_picker.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:package_info/package_info.dart';
import 'package:uuid/uuid.dart';

class Utils {
  static Future<bool> checkConnection() async {
    ConnectivityResult connectivityResult =
        await (Connectivity().checkConnectivity());
    if ((connectivityResult == ConnectivityResult.mobile) ||
        (connectivityResult == ConnectivityResult.wifi)) {
      return true;
    } else {
      return false;
    }
  }

  // ignore: missing_return
  static bool isAndroidPlatform() {
    if (Platform.isAndroid) {
      return true;
      // Android-specific code
    } else if (Platform.isIOS) {
      // iOS-specific code
      return false;
    }
  }

  static backPreviousScreen(BuildContext context, dynamic destinationPage) {
    if (isAndroidPlatform()) {
      SystemNavigator.pop();
    } else {
      Navigator.pop(context);
      Route route = MaterialPageRoute(builder: (context) => destinationPage);
      Navigator.pushReplacement(context, route);
    }
  }

  static Future<String> getPackageInfo() async {
    String infor;
    String appName;
    String packageName;
    String version;
    String buildNumber = "";
    try {
      PackageInfo packageInfo = await PackageInfo.fromPlatform();
      appName = packageInfo.appName;
      packageName = packageInfo.packageName;
      version = packageInfo.version;
      buildNumber = packageInfo.buildNumber;
      infor =
          'appName:$appName; packageName: $packageName; version: $version; buildNumber: $buildNumber';
    } on PlatformException catch (e) {
      print(e.message);
    }

    return infor;
  }

  static Future<String> getVersionPackageInfo() async {
    String version;
    try {
      PackageInfo packageInfo = await PackageInfo.fromPlatform();
      version = packageInfo.version;
    } on PlatformException catch (e) {
      print(e.message);
    }
    return version;
  }

  static Future<void> initDeviceId() async {
    String identifier = "";
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      identifier = await deviceIdPreferences.getPreferredDeviceID();
      if (Utils.isAndroidPlatform()) {
        var build = await deviceInfoPlugin.androidInfo;
        identifier =
            identifier == "" ? build.androidId : identifier; //UUID for Android
      } else {
        var data = await deviceInfoPlugin.iosInfo;
        identifier = identifier == ""
            ? data.identifierForVendor
            : identifier; //UUID for iOS
      }
      if (identifier != "")
        await deviceIdPreferences.setPreferredDeviceID(identifier);
      print("DeviceID: $identifier");
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  ///2021-4-7: tam comment ph, chi dung vn
  static Future<void> initServiceAPI(String countryCode) async {
    String _serviceAPIURL = "";
    try {
      _serviceAPIURL =
          await serviceCountryPreferences.getPreferredServiceCountryAPIURL();
      if (_serviceAPIURL == "") {
        var _country = [];
        _country = countryCode.replaceAll('-', '_').split('_');
        // if (_country.length > 1 && _country[1] == "VN") {
        //   await serviceCountryPreferences.setPreferredServiceCountry("+84");
        //   await serviceCountryPreferences
        //       .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
        // } else {
        //   await serviceCountryPreferences.setPreferredServiceCountry("+63");
        //   await serviceCountryPreferences
        //       .setPreferredServiceCountryAPIURL(FINAL_API_URL_PH);
        // }
        await serviceCountryPreferences.setPreferredServiceCountry("+84");
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      }
    } on PlatformException catch (e) {
      await serviceCountryPreferences.setPreferredServiceCountry("+84");
      await serviceCountryPreferences
          .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      print(e.message);
    }
  }

  static Future<void> saveServiceAPIByCountryCode(String countryCode) async {
    try {
      if (countryCode == "+84") {
        await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      } else {
        await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_PH);
      }
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static Future<void> saveServiceAPIByPhoneNumber(
      String countryCode, String phone) async {
    String _serviceAPI = '';

    if (phone.length >= 12) {
      String _startPhoneNumber = phone.substring(0, 12);

      ///Start Phone number '888888888888xxx' use for Dev
      if (_startPhoneNumber.contains('888888888888'))
        _serviceAPI = FINAL_API_URL_DEV;

      ///Start Phone number '999999999999xxx' use for Test
      else if (_startPhoneNumber.contains('999999999999'))
        _serviceAPI = FINAL_API_URL_TEST;

      ///other will get Service API Real
      else if (countryCode == "+84")
        _serviceAPI = FINAL_API_URL_VN;
      else
        _serviceAPI = FINAL_API_URL_PH;
    } else {
      ///other will get Service API VN Real
      if (countryCode == "+84")
        _serviceAPI = FINAL_API_URL_VN;
      ///other will get Service API PH Real
      else
        _serviceAPI = FINAL_API_URL_PH;
    }

    await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
    await serviceCountryPreferences
        .setPreferredServiceCountryAPIURL(_serviceAPI);
  }

  static Future<String> getDeviceDetails() async {
    String deviceInfor;
    String deviceName;
    String deviceVersion;
    String identifier = "";
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      identifier = await deviceIdPreferences.getPreferredDeviceID();

      if (isAndroidPlatform()) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceName = build.model;
        deviceVersion = build.version.release.toString();
        identifier =
            identifier == "" ? build.androidId : identifier; //UUID for Android
      } else {
        var data = await deviceInfoPlugin.iosInfo;
        deviceName = data.name;
        deviceVersion = data.systemVersion;
        identifier = identifier == ""
            ? data.identifierForVendor
            : identifier; //UUID for iOS
      }
    } on PlatformException catch (e) {
      print(e.message);
    }
    deviceInfor =
        'ID: $identifier; Model: $deviceName; Version: $deviceVersion';
    return deviceInfor;
  }

  static String getTypeDevice() {
    String deviceInfor = "";
    if (isAndroidPlatform())
      deviceInfor = "ANDROID";
    else
      deviceInfor = "IOS";
    return deviceInfor;
  }

  static Future<String> getVersionDevice() async {
    String deviceVersion;
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      if (isAndroidPlatform()) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceVersion = "Android " + build.version.release.toString();
      } else {
        var data = await deviceInfoPlugin.iosInfo;
        deviceVersion = "IOS " + data.systemVersion;
      }
    } on PlatformException catch (e) {
      print(e.message);
    }

    return deviceVersion;
  }

  static int getColorHexFromStr(String colorStr) {
    colorStr = "FF" + colorStr;
    colorStr = colorStr.replaceAll("#", "");
    int val = 0;
    int len = colorStr.length;
    for (int i = 0; i < len; i++) {
      int hexDigit = colorStr.codeUnitAt(i);
      if (hexDigit >= 48 && hexDigit <= 57) {
        val += (hexDigit - 48) * (1 << (4 * (len - 1 - i)));
      } else if (hexDigit >= 65 && hexDigit <= 70) {
        // A..F
        val += (hexDigit - 55) * (1 << (4 * (len - 1 - i)));
      } else if (hexDigit >= 97 && hexDigit <= 102) {
        // a..f
        val += (hexDigit - 87) * (1 << (4 * (len - 1 - i)));
      } else {
        throw new FormatException("An error occurred when converting a color");
      }
    }
    return val;
  }

  static String getSessionID() {
    var uuid = Uuid();
    return uuid.v1();
  }

  static Future<void> log(String logType, String subType, String info) async {
    Log log = new Log();
    log.logID = Utils.getSessionID();
    log.identity = await tokenPreferences.getPreferredIdentity();
    log.info = info;
    log.logType = logType;
    log.subType = subType;
    log.ver = await getVersionPackageInfo();
    log.os = await getVersionDevice();
    log.logTime = DateTime.now();

    final _logRepo = LogRepository();
    await _logRepo.insertLog(log);
  }

  static LocaleType getLocaleTypeDateTimePicker() {
    if (allTranslations.currentLanguage == 'vi')
      return LocaleType.vi;
    else
      return LocaleType.en;
  }

  static fieldFocusChange(
      BuildContext context, FocusNode currentFocus, FocusNode nextFocus) {
    currentFocus.unfocus();
    FocusScope.of(context).requestFocus(nextFocus);
  }

  static showSnackBar(BuildContext context, String text) {
    Scaffold.of(context).showSnackBar(SnackBar(
      content: Text(text),
    ));
  }

  static Widget separateLine(double height) {
    return new Container(
      height: height,
      width: ScreenConfig.screenWidth,
      color: Colors.grey.withOpacity(0.3),
    );
  }

  static String getPhoneRemoveFirstZero(String phone) {
    String _phone;
    if (phone.length <= 0 || phone.length <= 9)
      _phone = phone;
    else {
      String _numberFirst = phone.substring(0, 1);
      if (_numberFirst == '0')
        _phone = phone.substring(1, phone.length);
      else
        _phone = phone;
    }
    return _phone;
  }

  static String getFileExtension(String url) {
    String extension = "";
    if (url.indexOf("?") > -1) {
      url = url.substring(0, url.indexOf("?"));
    }
    if (url.lastIndexOf(".") == -1) {
      return extension;
    } else {
      extension = url.substring(url.lastIndexOf(".") + 1);
      if (extension.indexOf("%") > -1) {
        extension = extension.substring(0, extension.indexOf("%"));
      }
      if (extension.indexOf("/") > -1) {
        extension = extension.substring(0, extension.indexOf("/"));
      }
      return extension.toUpperCase();
    }
  }

  static bool isFilePicture(String url) {
    String extension = getFileExtension(url);
    if (extension == "JPG" ||
        extension == "JPEG" ||
        extension == "PNG" ||
        extension == "GIF" ||
        extension == "TIFF" ||
        extension == "BMP")
      return true;
    else
      return false;
  }

  static bool isFileVideo(String url) {
    String extension = getFileExtension(url);
    if (extension == "WMV" ||
        extension == "MP4" ||
        extension == "3GP" ||
        extension == "AVI" ||
        extension == "MPG" ||
        extension == "FLV" ||
        extension == "MP3" ||
        extension == "WMA")
      return true;
    else
      return false;
  }

  static bool isFilePDF(String url) {
    String extension = getFileExtension(url);
    if (extension == "PDF")
      return true;
    else
      return false;
  }

  static bool isFileDocument(String url) {
    String extension = getFileExtension(url);
    if (extension == "PPTX" ||
        extension == "PPT" ||
        extension == "DOC" ||
        extension == "DOCX" ||
        extension == "XLSX" ||
        extension == "XLS")
      return true;
    else
      return false;
  }

  static bool isServiceErrorSocket(String errorType) {
    var error1 = ServiceErrorType.SocketException.toString();
    var errorTimeout = ServiceErrorType.TimeoutException.toString();
    var error2 = errorType.toString();
    if (error1 == error2 || errorTimeout == error2)
      return true;
    else
      return false;
  }
}

==> hqsoft_core-0.0.60.tar.gz: lib/core_base/utility/util.dart <==
import 'dart:async';
import 'dart:io';

import 'package:connectivity/connectivity.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_datetime_picker/flutter_datetime_picker.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:package_info/package_info.dart';
import 'package:uuid/uuid.dart';
import 'package:flutter/foundation.dart' show kIsWeb;


class Utils {
  static Future<bool> checkConnection() async {
    ConnectivityResult connectivityResult =
        await (Connectivity().checkConnectivity());
    if ((connectivityResult == ConnectivityResult.mobile) ||
        (connectivityResult == ConnectivityResult.wifi)) {
      return true;
    } else {
      return false;
    }
  }

  // ignore: missing_return
  static bool isAndroidPlatform() {
    return Platform.isAndroid;
  }

  static backPreviousScreen(BuildContext context, dynamic destinationPage) {
    if (isAndroidPlatform()) {
      SystemNavigator.pop();
    } else {
      Navigator.pop(context);
      Route route = MaterialPageRoute(builder: (context) => destinationPage);
      Navigator.pushReplacement(context, route);
    }
  }

  static Future<String> getPackageInfo() async {
    late String info;
    String appName;
    String packageName;
    String version;
    String buildNumber = "";
    try {
      PackageInfo packageInfo = await PackageInfo.fromPlatform();
      appName = packageInfo.appName;
      packageName = packageInfo.packageName;
      version = packageInfo.version;
      buildNumber = packageInfo.buildNumber;
      info =
          'appName:$appName; packageName: $packageName; version: $version; buildNumber: $buildNumber';
    } on PlatformException catch (e) {
      print(e.message);
    }

    return info;
  }

  static Future<String> getVersionPackageInfo() async {
    late String version;
    try {
      PackageInfo packageInfo = await PackageInfo.fromPlatform();
      version = packageInfo.version;
    } on PlatformException catch (e) {
      print(e.message);
    }
    return version;
  }

  static Future<void> initDeviceId() async {
    String identifier = "";
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {

      if(kIsWeb){
        identifier = await deviceIdPreferences.getPreferredDeviceIDWeb();
        identifier = identifier.isEmpty ? Utils.getSessionID() : identifier;

      } else {
        identifier = await deviceIdPreferences.getPreferredDeviceID();

        if (Utils.isAndroidPlatform()) {
          var build = await deviceInfoPlugin.androidInfo;
          identifier = identifier.isEmpty
              ? build.androidId
              : identifier; //UUID for Android

        } else {
          var data = await deviceInfoPlugin.iosInfo;
          identifier = identifier.isEmpty
              ? data.identifierForVendor
              : identifier; //UUID for iOS
        }
      }

      if (identifier.isNotEmpty)
        await deviceIdPreferences.setPreferredDeviceID(identifier);
      print("DeviceID: $identifier");
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  ///2021-4-7: tam comment ph, chi dung vn
  static Future<void> initServiceAPI(String countryCode) async {
    String _serviceAPIURL = "";
    try {
      _serviceAPIURL =
          await serviceCountryPreferences.getPreferredServiceCountryAPIURL();
      if (_serviceAPIURL == "") {
        var _country = [];
        _country = countryCode.replaceAll('-', '_').split('_');
        // if (_country.length > 1 && _country[1] == "VN") {
        //   await serviceCountryPreferences.setPreferredServiceCountry("+84");
        //   await serviceCountryPreferences
        //       .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
        // } else {
        //   await serviceCountryPreferences.setPreferredServiceCountry("+63");
        //   await serviceCountryPreferences
        //       .setPreferredServiceCountryAPIURL(FINAL_API_URL_PH);
        // }
        await serviceCountryPreferences.setPreferredServiceCountry("+84");
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      }
    } on PlatformException catch (e) {
      await serviceCountryPreferences.setPreferredServiceCountry("+84");
      await serviceCountryPreferences
          .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      print(e.message);
    }
  }

  static Future<void> saveServiceAPIByCountryCode(String countryCode) async {
    try {
      if (countryCode == "+84") {
        await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_VN);
      } else {
        await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
        await serviceCountryPreferences
            .setPreferredServiceCountryAPIURL(FINAL_API_URL_PH);
      }
    } on PlatformException catch (e) {
      print(e.message);
    }
  }

  static Future<void> saveServiceAPIByPhoneNumber(
      String countryCode, String phone) async {
    String _serviceAPI = '';

    if (phone.length >= 12) {
      String _startPhoneNumber = phone.substring(0, 12);

      ///Start Phone number '888888888888xxx' use for Dev
      if (_startPhoneNumber.contains('888888888888'))
        _serviceAPI = FINAL_API_URL_DEV;

      ///Start Phone number '999999999999xxx' use for Test
      else if (_startPhoneNumber.contains('999999999999'))
        _serviceAPI = FINAL_API_URL_TEST;

      ///other will get Service API Real
      else if (countryCode == "+84")
        _serviceAPI = FINAL_API_URL_VN;
      else
        _serviceAPI = FINAL_API_URL_PH;
    } else {
      ///other will get Service API VN Real
      if (countryCode == "+84")
        _serviceAPI = FINAL_API_URL_VN;
      ///other will get Service API PH Real
      else
        _serviceAPI = FINAL_API_URL_PH;
    }

    await serviceCountryPreferences.setPreferredServiceCountry(countryCode);
    await serviceCountryPreferences
        .setPreferredServiceCountryAPIURL(_serviceAPI);
  }

  static Future<String> getDeviceDetails() async {
    late String deviceInfo;
    late String deviceName;
    late String deviceVersion;
    String identifier = "";
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      identifier = await deviceIdPreferences.getPreferredDeviceID();

      if (isAndroidPlatform()) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceName = build.model;
        deviceVersion = build.version.release.toString();
        identifier =
            identifier == "" ? build.androidId : identifier; //UUID for Android
      } else {
        var data = await deviceInfoPlugin.iosInfo;
        deviceName = data.name;
        deviceVersion = data.systemVersion;
        identifier = identifier == ""
            ? data.identifierForVendor
            : identifier; //UUID for iOS
      }
    } on PlatformException catch (e) {
      print(e.message);
    }
    deviceInfo =
        'ID: $identifier; Model: $deviceName; Version: $deviceVersion';
    return deviceInfo;
  }

  static String getTypeDevice() {
    String deviceInfor = "";
    if (isAndroidPlatform())
      deviceInfor = "ANDROID";
    else
      deviceInfor = "IOS";
    return deviceInfor;
  }

  static Future<String> getVersionDevice() async {
    late String deviceVersion;
    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      if (isAndroidPlatform()) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceVersion = "Android " + build.version.release.toString();
      } else {
        var data = await deviceInfoPlugin.iosInfo;
        deviceVersion = "IOS " + data.systemVersion;
      }
    } on PlatformException catch (e) {
      print(e.message);
    }

    return deviceVersion;
  }

  static int getColorHexFromStr(String colorStr) {
    colorStr = "FF" + colorStr;
    colorStr = colorStr.replaceAll("#", "");
    int val = 0;
    int len = colorStr.length;
    for (int i = 0; i < len; i++) {
      int hexDigit = colorStr.codeUnitAt(i);
      if (hexDigit >= 48 && hexDigit <= 57) {
        val += (hexDigit - 48) * (1 << (4 * (len - 1 - i)));
      } else if (hexDigit >= 65 && hexDigit <= 70) {
        // A..F
        val += (hexDigit - 55) * (1 << (4 * (len - 1 - i)));
      } else if (hexDigit >= 97 && hexDigit <= 102) {
        // a..f
        val += (hexDigit - 87) * (1 << (4 * (len - 1 - i)));
      } else {
        throw new FormatException("An error occurred when converting a color");
      }
    }
    return val;
  }

  static String getSessionID() {
    var uuid = Uuid();
    return uuid.v1();
  }

  static Future<void> log(String logType, String subType, String info) async {
    Log log = new Log();
    log.logID = Utils.getSessionID();
    log.identity = await tokenPreferences.getPreferredIdentity();
    log.info = info;
    log.logType = logType;
    log.subType = subType;
    log.ver = await getVersionPackageInfo();
    log.os = await getVersionDevice();
    log.logTime = DateTime.now();

    final _logRepo = LogRepository();
    await _logRepo.insertLog(log);
  }

  static LocaleType getLocaleTypeDateTimePicker() {
    if (allTranslations.currentLanguage == 'vi')
      return LocaleType.vi;
    else
      return LocaleType.en;
  }

  static fieldFocusChange(
      BuildContext context, FocusNode currentFocus, FocusNode nextFocus) {
    currentFocus.unfocus();
    FocusScope.of(context).requestFocus(nextFocus);
  }

  static showSnackBar(BuildContext context, String text) {
    ScaffoldMessenger.of(context).showSnackBar(SnackBar(
      content: Text(text),
    ));
  }

  static Widget separateLine(double height) {
    return new Container(
      height: height,
      width: ScreenConfig.screenWidth,
      color: Colors.grey.withOpacity(0.3),
    );
  }

  static String getPhoneRemoveFirstZero(String phone) {
    String _phone;
    if (phone.length <= 0 || phone.length <= 9)
      _phone = phone;
    else {
      String _numberFirst = phone.substring(0, 1);
      if (_numberFirst == '0')
        _phone = phone.substring(1, phone.length);
      else
        _phone = phone;
    }
    return _phone;
  }

  static String getFileExtension(String url) {
    String extension = "";
    if (url.indexOf("?") > -1) {
      url = url.substring(0, url.indexOf("?"));
    }
    if (url.lastIndexOf(".") == -1) {
      return extension;
    } else {
      extension = url.substring(url.lastIndexOf(".") + 1);
      if (extension.indexOf("%") > -1) {
        extension = extension.substring(0, extension.indexOf("%"));
      }
      if (extension.indexOf("/") > -1) {
        extension = extension.substring(0, extension.indexOf("/"));
      }
      return extension.toUpperCase();
    }
  }

  static bool isFilePicture(String url) {
    String extension = getFileExtension(url);
    if (extension == "JPG" ||
        extension == "JPEG" ||
        extension == "PNG" ||
        extension == "GIF" ||
        extension == "TIFF" ||
        extension == "BMP")
      return true;
    else
      return false;
  }

  static bool isFileVideo(String url) {
    String extension = getFileExtension(url);
    if (extension == "WMV" ||
        extension == "MP4" ||
        extension == "3GP" ||
        extension == "AVI" ||
        extension == "MPG" ||
        extension == "FLV" ||
        extension == "MP3" ||
        extension == "WMA")
      return true;
    else
      return false;
  }

  static bool isFilePDF(String url) {
    String extension = getFileExtension(url);
    if (extension == "PDF")
      return true;
    else
      return false;
  }

  static bool isFileDocument(String url) {
    String extension = getFileExtension(url);
    if (extension == "PPTX" ||
        extension == "PPT" ||
        extension == "DOC" ||
        extension == "DOCX" ||
        extension == "XLSX" ||
        extension == "XLS")
      return true;
    else
      return false;
  }

  static bool isServiceErrorSocket(String errorType) {
    var error1 = ServiceErrorType.SocketException.toString();
    var errorTimeout = ServiceErrorType.TimeoutException.toString();
    var error2 = errorType.toString();
    if (error1 == error2 || errorTimeout == error2)
      return true;
    else
      return false;
  }
}
